pub enum RenderMeshInstances {
CpuBuilding(RenderMeshInstancesCpu),
GpuBuilding(RenderMeshInstancesGpu),
}Expand description
Information that the render world keeps about each entity that contains a mesh.
The set of information needed is different depending on whether CPU or GPU
MeshUniform building is in use.
Variants
CpuBuilding(RenderMeshInstancesCpu)
Information needed when using CPU mesh instance data building.
GpuBuilding(RenderMeshInstancesGpu)
Information needed when using GPU mesh instance data building.
Implementations
Sourceimpl RenderMeshInstances
impl RenderMeshInstances
Sourcepub fn mesh_asset_id(&self, entity: MainEntity) -> Option<AssetId<Mesh>>
pub fn mesh_asset_id(&self, entity: MainEntity) -> Option<AssetId<Mesh>>
Returns the ID of the mesh asset attached to the given entity, if any.
Sourcepub fn render_mesh_queue_data(
&self,
entity: MainEntity,
) -> Option<RenderMeshQueueData<'_>>
pub fn render_mesh_queue_data( &self, entity: MainEntity, ) -> Option<RenderMeshQueueData<'_>>
Constructs RenderMeshQueueData for the given entity, if it has a
mesh attached.