extract_entities_that_need_specializations_removed

Function extract_entities_that_need_specializations_removed 

pub fn extract_entities_that_need_specializations_removed<M>(
    entities_needing_specialization: Extract<'_, '_, Res<'_, EntitiesNeedingSpecialization<M>>>,
    dirty_specializations: ResMut<'_, DirtySpecializations>,
)
where M: Material,
A system that adds entities that were judged to need their specializations removed to the appropriate table in DirtySpecializations.