extract_shadow_lod_origin

Function extract_shadow_lod_origin 

pub fn extract_shadow_lod_origin(
    global_transform_query: Extract<'_, '_, Query<'_, '_, &GlobalTransform>>,
    camera_query: Extract<'_, '_, Query<'_, '_, (Entity, &RenderTarget), With<Camera>>>,
    shadow_lod_origin_query: Extract<'_, '_, Query<'_, '_, Entity, With<ShadowLodOrigin>>>,
    lights_query: Extract<'_, '_, Query<'_, '_, Entity, Or<(With<PointLight>, With<SpotLight>)>>>,
    render_shadow_lod_origin: ResMut<'_, RenderShadowLodOrigin>,
)
An extraction system that determines the origin for LOD computation for point and spot light shadow maps and updates the RenderShadowLodOrigin with the result.

See ShadowLodOrigin for more details on the algorithm that this system uses.