pub struct GpuClusteredLight { /* private fields */ }Expand description
The GPU-side structure that stores information about a clustered light (point or spot).
This is not used for other clustered objects, such as light probes.