#[repr(C)]pub struct MeshCullingData {
pub aabb_center: Vec4,
pub aabb_half_extents: Vec4,
}Expand description
Information about each mesh instance needed to cull it on GPU.
This consists of its axis-aligned bounding box (AABB).
Fields
aabb_center: Vec4The 3D center of the AABB in model space, padded with an extra unused float value.
aabb_half_extents: Vec4The 3D extents of the AABB in model space, divided by two, padded with an extra unused float value.