pub struct MeshPhaseBindGroups { /* private fields */ }Expand description
The bind groups for meshes currently loaded.
If GPU mesh preprocessing isn’t in use, these are global to the scene. If GPU mesh preprocessing is in use, these are specific to a single phase.
Implementations
Sourceimpl MeshPhaseBindGroups
impl MeshPhaseBindGroups
Sourcepub fn new(render_device: &RenderDevice) -> MeshPhaseBindGroups
pub fn new(render_device: &RenderDevice) -> MeshPhaseBindGroups
Creates a new, blank, set of bind groups for this phase.
Bind groups must be added to the resulting MeshPhaseBindGroups
explicitly.
pub fn reset(&mut self)
Sourcepub fn get(
&self,
lightmap: Option<LightmapSlabIndex>,
is_skinned: bool,
morph: MeshMorphBindGroupKey,
motion_vectors: bool,
) -> Option<&BindGroup>
pub fn get( &self, lightmap: Option<LightmapSlabIndex>, is_skinned: bool, morph: MeshMorphBindGroupKey, motion_vectors: bool, ) -> Option<&BindGroup>
Get the appropriate BindGroup for RenderMesh with the given keys.