PbrPlugin

Struct PbrPlugin 

pub struct PbrPlugin {
    pub prepass_enabled: bool,
    pub add_default_deferred_lighting_plugin: bool,
    pub use_gpu_instance_buffer_builder: bool,
    pub debug_flags: RenderDebugFlags,
    pub gltf_enable_standard_materials: bool,
}
Sets up the entire PBR infrastructure of bevy.

Fields

prepass_enabled: bool

Controls if the prepass is enabled for the StandardMaterial. For more information about what a prepass is, see the bevy_core_pipeline::prepass docs.

add_default_deferred_lighting_plugin: bool

Controls if DeferredPbrLightingPlugin is added.

use_gpu_instance_buffer_builder: bool

Controls if GPU MeshUniform building is enabled.

This requires compute shader support and so will be forcibly disabled if the platform doesn’t support those.

debug_flags: RenderDebugFlags

Debugging flags that can optionally be set when constructing the renderer.

gltf_enable_standard_materials: bool

Builds and inserts StandardMaterial when loading glTF files