pub struct RenderMeshInstanceCpu {
pub shared: RenderMeshInstanceSharedFlatBlob,
pub transforms: MeshTransforms,
pub render_layers: Option<RenderLayers>,
}Expand description
CPU data that the render world keeps for each entity, when not using GPU mesh uniform building.
Fields
Data shared between both the CPU mesh uniform building and the GPU mesh uniform building paths.
transforms: MeshTransformsThe transform of the mesh.
This will be written into the MeshUniform at the appropriate time.
render_layers: Option<RenderLayers>The set of render layers that this mesh belongs to.
Methods from Deref<Target = RenderMeshInstanceSharedFlatBlob>