pub struct RenderMeshInstanceFlags(/* private fields */);Expand description
Various useful flags for [RenderMeshInstance]s.
Implementations
Sourceimpl RenderMeshInstanceFlags
impl RenderMeshInstanceFlags
Sourcepub const SHADOW_CASTER: Self
pub const SHADOW_CASTER: Self
The mesh casts shadows.
Sourcepub const AUTOMATIC_BATCHING: Self
pub const AUTOMATIC_BATCHING: Self
The mesh can participate in automatic batching.
Sourcepub const HAS_PREVIOUS_TRANSFORM: Self
pub const HAS_PREVIOUS_TRANSFORM: Self
The mesh had a transform last frame and so is eligible for motion vector computation.
Sourcepub const HAS_PREVIOUS_SKIN: Self
pub const HAS_PREVIOUS_SKIN: Self
The mesh had a skin last frame and so that skin should be taken into account for motion vector computation.
Sourcepub const HAS_PREVIOUS_MORPH: Self
pub const HAS_PREVIOUS_MORPH: Self
The mesh had morph targets last frame and so they should be taken into account for motion vector computation.
Sourcepub const NO_CPU_CULLING: Self
pub const NO_CPU_CULLING: Self
CPU culling has been disabled because the NoCpuCulling component
is present on the mesh instance.
Sourceimpl RenderMeshInstanceFlags
impl RenderMeshInstanceFlags
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<Self>
pub const fn from_bits(bits: u32) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> Self
pub const fn from_bits_truncate(bits: u32) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> Self
pub const fn from_bits_retain(bits: u32) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl RenderMeshInstanceFlags
impl RenderMeshInstanceFlags
Sourcepub const fn iter(&self) -> Iter<RenderMeshInstanceFlags>
pub const fn iter(&self) -> Iter<RenderMeshInstanceFlags>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<RenderMeshInstanceFlags>
pub const fn iter_names(&self) -> IterNames<RenderMeshInstanceFlags>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.