pub struct RenderViewLightProbes<C>where
C: LightProbeComponent,{
pub binding_index_to_textures: Vec<C::AssetId>,
pub main_entity_to_render_light_probe_index: MainEntityHashMap<u32>,
/* private fields */
}Expand description
A component, part of the render world, that stores the mapping from asset ID or IDs to the texture index in the appropriate binding arrays.
Cubemap textures belonging to environment maps are collected into binding arrays, and the index of each texture is presented to the shader for runtime lookup. 3D textures belonging to reflection probes are likewise collected into binding arrays, and the shader accesses the 3D texture by index.
This component is attached to each view in the render world, because each view may have a different set of light probes that it considers and therefore the texture indices are per-view.
Fields
binding_index_to_textures: Vec<C::AssetId>The list of environment maps presented to the shader, in order.
main_entity_to_render_light_probe_index: MainEntityHashMap<u32>A mapping from the main world entity to the index in
render_light_probes.