pub struct ShadowBatchSetKey {
pub pipeline: CachedRenderPipelineId,
pub draw_function: DrawFunctionId,
pub material_bind_group_index: Option<u32>,
pub slabs: MeshSlabs,
}Expand description
Information that must be identical in order to place opaque meshes in the same batch set.
A batch set is a set of batches that can be multi-drawn together, if multi-draw is in use.
Fields
pipeline: CachedRenderPipelineIdThe identifier of the render pipeline.
draw_function: DrawFunctionIdThe function used to draw.
material_bind_group_index: Option<u32>The ID of a bind group specific to the material.
In the case of PBR, this is the MaterialBindGroupIndex.
slabs: MeshSlabsThe IDs of the slabs of GPU memory in the mesh allocator that contain the mesh data.
For non-mesh items, you can fill the MeshSlabs::vertex_slab_id with
0 if your items can be multi-drawn, or with a unique value if they
can’t.