pub enum MeshMorphTargetBindGroups {
Uniform(HashMap<AssetId<Mesh>, MeshBindGroupPair>),
Storage(HashMap<MeshSlabId, MeshMorphTargetStorageBindGroups>),
}Expand description
Stores bind groups for each mesh with morph targets.
If storage buffers aren’t available on this platform, we use a single bind group per mesh. If they are available, however, we use a single bind group per morph target slab ID (managed by the mesh allocator).
Variants
Uniform(HashMap<AssetId<Mesh>, MeshBindGroupPair>)
Maps a mesh asset ID to the bind group for that mesh.
We use morph target images on platforms without storage buffers, and as such platforms don’t support bindless textures either, we must use a single bind group per morphable mesh.
Storage(HashMap<MeshSlabId, MeshMorphTargetStorageBindGroups>)
Maps a morph target slab ID that the mesh allocator manages to the bind groups for morph displacements in that slab.