pub fn per_view_shadow_pass<const IS_LATE: bool>(
world: &World,
view: ViewQuery<'_, '_, &ViewLightEntities>,
view_light_query: Query<'_, '_, (&ShadowView, &ExtractedView, Has<OcclusionCulling>)>,
shadow_render_phases: Res<'_, ViewBinnedRenderPhases<Shadow>>,
ctx: RenderContext<'_, '_>,
)Expand description
Renders the shadow maps that are associated with a specific view.
At present, these consist of the directional light shadows.