pub struct MeshCullingDataBuffer(/* private fields */);Expand description
A GPU buffer that holds the information needed to cull meshes on GPU.
At the moment, this simply holds each mesh’s AABB.
To avoid wasting CPU time in the CPU culling case, this buffer will be empty if GPU culling isn’t in use.
Methods from Deref<Target = AtomicSparseBufferVec<MeshCullingData>>
Sourcepub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> bool
Returns true if there are no elements in the CPU side copy of the buffer.
Sourcepub fn buffer(&self) -> Option<&Buffer>
pub fn buffer(&self) -> Option<&Buffer>
Returns a handle to the buffer, if the data has been uploaded.
Sourcepub fn set(&self, index: u32, value: T)
pub fn set(&self, index: u32, value: T)
Sets the value at the given index.
If the index isn’t in range of the buffer, this method panics.
Internally, the value is converted to its blob representation.
Note that this method is thread-safe and doesn’t require &mut self.
It’s your responsibility, however, to ensure synchronization; though
this method is memory-safe, it’s possible for other threads to observe
partially-overwritten values if Self::get or similar methods are
called while the write operation is occurring.
Sourcepub fn reserve(&mut self, new_capacity: usize, render_device: &RenderDevice)
pub fn reserve(&mut self, new_capacity: usize, render_device: &RenderDevice)
Ensures that the backing buffer for this buffer vector is present and appropriately sized on the GPU.
Sourcepub fn grow(&mut self, new_len: u32)
pub fn grow(&mut self, new_len: u32)
Grows the buffer by adding default values so that it’s at least the given size.
If the buffer is already large enough, this method does nothing.
Sourcepub fn truncate(&mut self, len: u32)
pub fn truncate(&mut self, len: u32)
Truncates the buffer to the given length.
If the buffer is already that length or shorter, this method does nothing.
Sourcepub fn write_buffers(
&mut self,
render_device: &RenderDevice,
render_queue: &RenderQueue,
)
pub fn write_buffers( &mut self, render_device: &RenderDevice, render_queue: &RenderQueue, )
Writes the data to the GPU, either via a sparse upload or a bulk data upload.
Sourcepub fn prepare_to_populate_buffers(
&mut self,
render_device: &RenderDevice,
pipeline_cache: &PipelineCache,
sparse_buffer_update_jobs: &mut SparseBufferUpdateJobs,
sparse_buffer_update_bind_groups: &mut SparseBufferUpdateBindGroups,
sparse_buffer_update_pipelines: &SparseBufferUpdatePipelines,
)
pub fn prepare_to_populate_buffers( &mut self, render_device: &RenderDevice, pipeline_cache: &PipelineCache, sparse_buffer_update_jobs: &mut SparseBufferUpdateJobs, sparse_buffer_update_bind_groups: &mut SparseBufferUpdateBindGroups, sparse_buffer_update_pipelines: &SparseBufferUpdatePipelines, )
If a sparse update has been scheduled, prepares all GPU resources necessary to perform a sparse buffer update, other than updating the metadata uniform.