pub struct PreprocessPipelines {
pub direct_preprocess: PreprocessPipeline,
pub gpu_frustum_culling_preprocess: PreprocessPipeline,
pub early_gpu_occlusion_culling_preprocess: PreprocessPipeline,
pub late_gpu_occlusion_culling_preprocess: PreprocessPipeline,
pub gpu_frustum_culling_build_indexed_indirect_params: BuildIndirectParametersPipeline,
pub gpu_frustum_culling_build_non_indexed_indirect_params: BuildIndirectParametersPipeline,
pub early_phase: PreprocessPhasePipelines,
pub late_phase: PreprocessPhasePipelines,
pub main_phase: PreprocessPhasePipelines,
pub bin_unpacking: BinUnpackingPipeline,
}Expand description
The compute shader pipelines for the GPU mesh preprocessing and indirect parameter building passes.
Fields
direct_preprocess: PreprocessPipelineThe pipeline used for CPU culling. This pipeline doesn’t populate indirect parameter metadata.
gpu_frustum_culling_preprocess: PreprocessPipelineThe pipeline used for mesh preprocessing when GPU frustum culling is in use, but occlusion culling isn’t.
This pipeline populates indirect parameter metadata.
early_gpu_occlusion_culling_preprocess: PreprocessPipelineThe pipeline used for the first phase of occlusion culling.
This pipeline culls, transforms meshes, and populates indirect parameter metadata.
late_gpu_occlusion_culling_preprocess: PreprocessPipelineThe pipeline used for the second phase of occlusion culling.
This pipeline culls, transforms meshes, and populates indirect parameter metadata.
gpu_frustum_culling_build_indexed_indirect_params: BuildIndirectParametersPipelineThe pipeline that builds indirect draw parameters for indexed meshes, when frustum culling is enabled but occlusion culling isn’t enabled.
gpu_frustum_culling_build_non_indexed_indirect_params: BuildIndirectParametersPipelineThe pipeline that builds indirect draw parameters for non-indexed meshes, when frustum culling is enabled but occlusion culling isn’t enabled.
early_phase: PreprocessPhasePipelinesCompute shader pipelines for the early prepass phase that draws meshes visible in the previous frame.
late_phase: PreprocessPhasePipelinesCompute shader pipelines for the late prepass phase that draws meshes that weren’t visible in the previous frame, but became visible this frame.
main_phase: PreprocessPhasePipelinesCompute shader pipelines for the main color phase.
bin_unpacking: BinUnpackingPipelineCompute shader pipelines for the bin unpacking step.